<?php
/**
 * PHPShop Module Actions
 *
 * This script defines several action functions for managing a PHPShop module.
 * It handles updating the module version, updating settings, and displaying module configuration.
 *
 * @package VtbPay
 */
 
$PHPShopOrm = new PHPShopOrm($PHPShopModules->getParam('base.vtbpay.vtbpay_system'));


/**
 * Update the module version
 *
 * This function updates the version of the module.
 *
 * @global object $PHPShopModules The PHPShopModules instance for managing modules.
 * @global object $PHPShopOrm The PHPShopOrm instance for database operations.
 *
 * @return mixed Returns the result of the update action.
 */
function actionBaseUpdate() 
{
    global $PHPShopModules, $PHPShopOrm;
    $PHPShopOrm->clean();
    $option = $PHPShopOrm->select();
    $new_version = $PHPShopModules->getUpdate($option['version']);
    $PHPShopOrm->clean();
    $action = $PHPShopOrm->update(array('version_new' => $new_version));
    header('Location: ?path=modules&id='.$_GET['id']);
    return $action;
}


/**
 * Update module settings
 *
 * This function updates the settings of the module.
 *
 * @global object $PHPShopModules The PHPShopModules instance for managing modules.
 * @global object $PHPShopOrm The PHPShopOrm instance for database operations.
 *
 * @return mixed Returns the result of the update action.
 */
function actionUpdate()
{
    global $PHPShopOrm,$PHPShopModules;
    
    //  
    $PHPShopModules->updateOption($_GET['id'], $_POST['servers']);

    if (empty($_POST['test_mode_new'])) $_POST['test_mode_new'] = 0;
    if (empty($_POST['logging_new'])) $_POST['logging_new'] = 0;

    $PHPShopOrm->debug = false;
    $action = $PHPShopOrm->update($_POST);
    header('Location: ?path=modules&id=' . $_GET['id']);

    return $action;
}


/**
 * Display module configuration settings
 *
 * This function displays the configuration settings for the module.
 *
 * @global object $PHPShopGUI The PHPShopGUI instance for handling GUI components.
 * @global object $PHPShopOrm The PHPShopOrm instance for database operations.
 *
 * @return bool Returns true on successful display of the configuration, false otherwise.
 */
function actionStart()
{
    global $PHPShopGUI, $PHPShopOrm;

    PHPShopObj::loadClass('order');

    $PHPShopOrm->objBase = $GLOBALS['SysValue']['base']['vtbpay']['vtbpay_system'];
    $data = $PHPShopOrm->select();

    // Build the configuration tabs and fields
    $Tab1 = $PHPShopGUI->setField('Client ID', $PHPShopGUI->setInput('text.', 'client_id_new', $data['client_id'], false, 300));
    $Tab1 .= $PHPShopGUI->setField('Client Secret', $PHPShopGUI->setInput('text.', 'client_secret_new', $data['client_secret'], false, 300));
    $Tab1 .= $PHPShopGUI->setField('Merchant-Authorization', $PHPShopGUI->setInputText(false, 'merchant_authorization_new', $data['merchant_authorization'], 300));
    $Tab1 .= $PHPShopGUI->setField('  ', $PHPShopGUI->setCheckbox('test_mode_new', 1, '       .', $data['test_mode']));
    $Tab1 .= $PHPShopGUI->setField(' ', $PHPShopGUI->setCheckbox('logging_new', 1, '           API.', $data['logging']));
    $Tab1 .= $PHPShopGUI->setField('  ', $PHPShopGUI->setInputText(false, 'btn_text_new', $data['btn_text'], 300));
    $Tab1 .= $PHPShopGUI->setField(' ', $PHPShopGUI->setTextarea('payment_info_new', $data['payment_info']));
    
    // Build the order status dropdown values
    $PHPShopOrderStatusArray = new PHPShopOrderStatusArray();
    $OrderStatusArray = $PHPShopOrderStatusArray->getArray();
    $orderStatusValue[] = [__(' '), 0, $data['transaction_end_status']];
    if (is_array($OrderStatusArray))
        foreach ($OrderStatusArray as $orderStatus)
            $orderStatusValue[] = [$orderStatus['name'], $orderStatus['id'], $data['transaction_end_status']];

    $Tab1 .= $PHPShopGUI->setField('   :', $PHPShopGUI->setSelect('transaction_end_status_new', $orderStatusValue, 300), '', '', 'transaction-end-status');   

    // Registration form
    $Tab3 = $PHPShopGUI->setPay(null, false, $data['version'], false);
    
    // Build the configuration tabs
    $PHPShopGUI->setTab(
      ['', $Tab1, true],
      [' ', $Tab3]
    );

    // Build the footer content with save and exit buttons
    $ContentFooter =
        $PHPShopGUI->setInput('hidden', 'rowID', $data['id']) .
        $PHPShopGUI->setInput('submit', 'saveID', '', 'right', 80, '', 'but', 'actionUpdate.modules.edit');

    $PHPShopGUI->setFooter($ContentFooter);

    return true;
}

// Handle events
$PHPShopGUI->getAction();

// Display form on start
$PHPShopGUI->setAction($_GET['id'], 'actionStart');
