<?php
require_once(dirname(__FILE__) . '/Api.php');

class VtbApi extends Api
{
    private static string $tokenUrl;

    private static string $orderUrl;

    private static string $mode;

    private static string $clientMerchant;
    private static array $clientData = [
        'grant_type' => 'client_credentials'
    ];

    private static array $modeUrls = [
        'PROD' => [
            'TOKEN' => 'https://open.api.vtb.ru:443/passport/oauth2/token',
            'ORDER' => 'https://gw.api.vtb.ru/openapi/smb/efcp/e-commerce/v1/orders'
        ],
        'TEST' => [
            'TOKEN' => 'https://auth.bankingapi.ru/auth/realms/kubernetes/protocol/openid-connect/token',
            'ORDER' => 'https://hackaton.bankingapi.ru/api/smb/efcp/e-commerce/api/v1/orders'
        ]
    ];

    public function __construct(
        $clientId = false,
        $clientSecret = false,
        $test = false,
        $merchant = ''
    ) {
        self::$clientData['client_id'] = $clientId;
        self::$clientData['client_secret'] = $clientSecret;
        self::$clientMerchant = (!empty($merchant)) ? $merchant : '';
        self::$mode = $test ? 'TEST': 'PROD';

        self::$tokenUrl = self::$modeUrls[self::$mode]['TOKEN'];
        self::$orderUrl = self::$modeUrls[self::$mode]['ORDER'];
    }

    public function getAccessToken() {
        $result = $this->sendRequest(
            self::$tokenUrl,
            http_build_query(self::$clientData),
            [
                'Content-Type: application/x-www-form-urlencoded',
                'Merchant-Authorization: ' . self::$clientMerchant
            ]
        );

        return $result;
    }

    public function getOrderLink(
        string $orderId,
        string $email,
        int $orderCreate,
        float $amount,
        string $returnUrl
    ) {
        $result = false;
        $args = [];
        $headers = $this->getAutorizationHeaders();
        $merchant = self::$clientMerchant;

        if ($headers) {
            $headers[] = 'Content-Type: application/json';
            if ($merchant) {
                $headers[] = 'Merchant-Authorization: ' . $merchant;
            }

            $timestamp = $orderCreate + 86400; // +1d
            $expire = date('Y-m-d\TH:i:s.v\Z', $timestamp); // ISO 8601

            $args = [
                'orderId' => $orderId,
                'orderName' => 'Заказ #' . $orderId,
                'customer' => [
                    'email' => $email
                ],
                'amount' => [
                    'value' => $amount,
                    'code' => 'RUB'
                ],
                'expire' => $expire,
                'returnUrl' => $returnUrl
            ];

            $result = $this->sendRequest(
                self::$orderUrl,
                json_encode($args),
                $headers
            );
        }

        return $result;
    }

    public function getOrderInfo(string $orderId)
    {
        $result = false;
        $headers = $this->getAutorizationHeaders();
        $merchant = self::$clientMerchant;

        if ($headers) {
            $headers[] = 'Content-Type: application/json';
            if ($merchant) {
                $headers[] = 'Merchant-Authorization: ' . $merchant;
            }

            $result = $this->sendRequest(
                self::$orderUrl . '/' . $orderId,
                json_encode([]),
                $headers,
                'GET'
            );
        }

        return $result;
    }

    private function getAutorizationHeaders()
    {
        $result = false;
        $token = $this->getAccessToken();

        if (is_array($token) && isset($token['access_token'])) {
            $result = [
                'X-IBM-Client-Id: ' . explode('@', self::$clientData['client_id'])[0],
                'Authorization: ' . $token['token_type'] . ' ' . $token['access_token'],
            ];
        }

        return $result;
    }
}
