<?php
class VtbPayLogger
{
    /**
     * Constants for log levels
     */
    const LOG_LEVEL_DEBUG = 'DEBUG';
    const LOG_LEVEL_ERROR = 'ERROR';

    /**
     * @var string The path to the log file
     */
    private $logFilePath;
    

    /**
     * VtbPayLogger constructor.
     *
     * @param string $fileName The path to the log file
     */
    public function __construct($fileName)
    {
        $this->logFilePath = $fileName;
        $this->createLogDirectory();
    }
    

    /**
     * Logs a message with optional context. Log type can be either DEBUG or ERROR.
     *
     * @param string $message The message to log
     * @param string $type The type of log. Can be either DEBUG or ERROR
     * @param array $context An optional array of context data to log with the message
     * @param bool $print_r If set to true, the context array will be printed using print_r instead of json_encode
     * @return void
     */
    public function log(
        $message,
        $type = self::LOG_LEVEL_DEBUG,
        $context = [],
        $print_r = false
    ) {
        $message = '[' . date('Y-m-d H:i:s') . '] ' . $type . ' ' . $message;

        if (!empty($context) && is_array($context)) {
            $message .= ' Context: ' . PHP_EOL;
            $message .= $print_r ? print_r($context, true) . PHP_EOL : json_encode($context);
        }

        file_put_contents($this->logFilePath, $message . PHP_EOL, FILE_APPEND);
    }


    /**
     * Creates the log directory (if needed) for the log file.
     *
     * @return void
     */
    private function createLogDirectory()
    {
        $logDirectory = dirname($this->logFilePath);
        if (!is_dir($logDirectory)) {
            mkdir($logDirectory, 0777, true);
        }
    }
}
